@@ -55,7 +55,7 @@ static noinline void duckbill_init(void)
 
 	pr_debug("initializing SDRAM...\n");
 
-	mx28_mem_init();
+	mx28_mem_init(mx28_dram_vals_default);
 
 	pr_debug("DONE\n");
 }
