@@ -15,9 +15,6 @@
  */
 
 #include <common.h>
-#include <linux/sizes.h>
-#include <asm/barebox-arm.h>
-#include <asm/barebox-arm-head.h>
 #include <mach/lowlevel.h>
 #include <mach/lowlevel-dvc.h>
 
@@ -25,15 +22,11 @@ extern char __dtb_tegra124_jetson_tk1_start[];
 
 ENTRY_FUNCTION(start_nvidia_jetson, r0, r1, r2)
 {
-	uint32_t fdt;
-
-	tegra_cpu_lowlevel_setup();
+	tegra_cpu_lowlevel_setup(__dtb_tegra124_jetson_tk1_start);
 
 	tegra_dvc_init();
 	tegra124_dvc_pinmux();
 	tegra124_as3722_enable_essential_rails(0x3c00);
 
-	fdt = (uint32_t)__dtb_tegra124_jetson_tk1_start - get_runtime_offset();
-
-	tegra_avp_reset_vector(fdt);
+	tegra_avp_reset_vector();
 }
